@@ -15,7 +15,8 @@ class DjangoSecurePasswordInputWidget(PasswordInput):
 
     class Media:
         js = [
-            "jquery3/jquery.js",
+            "admin/js/vendor/jquery/jquery.js",
             "django-secure-password-input/js/jsencrypt.js",
             "django-secure-password-input/js/enable-jsencrypt.js",
+            "admin/js/jquery.init.js"
         ]
